# coding: utf-8

# flake8: noqa

"""
    Nomad Hawk

    This is the API descriptor for the Nomad Hawk API, responsible for tracking and analytics.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.connector_api import ConnectorApi
from swagger_client.api.track_api import TrackApi

# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.api_response import ApiResponse
from swagger_client.models.connector import Connector
from swagger_client.models.connector_api import ConnectorApi
from swagger_client.models.connector_mapping import ConnectorMapping
from swagger_client.models.connector_mapping_map_to import ConnectorMappingMapTo
from swagger_client.models.event import Event
from swagger_client.models.inline_response_200 import InlineResponse200



# coding: utf-8

"""
    Nomad Hawk

    This is the API descriptor for the Nomad Hawk API, responsible for tracking and analytics.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.api_response import ApiResponse  # noqa: E501
from swagger_client.rest import ApiException


class TestApiResponse(unittest.TestCase):
    """ApiResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiResponse(self):
        """Test ApiResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.api_response.ApiResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Hawk

    This is the API descriptor for the Nomad Hawk API, responsible for tracking and analytics.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'category': 'str',
        'label': 'str',
        'message': 'str',
        'value': 'str',
        'value_type': 'str',
        'source': 'str',
        'sales_channel': 'str',
        'user': 'str'
    }

    attribute_map = {
        'type': 'type',
        'category': 'category',
        'label': 'label',
        'message': 'message',
        'value': 'value',
        'value_type': 'value_type',
        'source': 'source',
        'sales_channel': 'sales_channel',
        'user': 'user'
    }

    def __init__(self, type=None, category=None, label=None, message=None, value=None, value_type=None, source=None, sales_channel=None, user=None):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._category = None
        self._label = None
        self._message = None
        self._value = None
        self._value_type = None
        self._source = None
        self._sales_channel = None
        self._user = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if category is not None:
            self.category = category
        if label is not None:
            self.label = label
        if message is not None:
            self.message = message
        if value is not None:
            self.value = value
        if value_type is not None:
            self.value_type = value_type
        if source is not None:
            self.source = source
        if sales_channel is not None:
            self.sales_channel = sales_channel
        if user is not None:
            self.user = user

    @property
    def type(self):
        """Gets the type of this Event.  # noqa: E501


        :return: The type of this Event.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Event.


        :param type: The type of this Event.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def category(self):
        """Gets the category of this Event.  # noqa: E501


        :return: The category of this Event.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Event.


        :param category: The category of this Event.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def label(self):
        """Gets the label of this Event.  # noqa: E501


        :return: The label of this Event.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Event.


        :param label: The label of this Event.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def message(self):
        """Gets the message of this Event.  # noqa: E501


        :return: The message of this Event.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Event.


        :param message: The message of this Event.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def value(self):
        """Gets the value of this Event.  # noqa: E501


        :return: The value of this Event.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Event.


        :param value: The value of this Event.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def value_type(self):
        """Gets the value_type of this Event.  # noqa: E501


        :return: The value_type of this Event.  # noqa: E501
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this Event.


        :param value_type: The value_type of this Event.  # noqa: E501
        :type: str
        """

        self._value_type = value_type

    @property
    def source(self):
        """Gets the source of this Event.  # noqa: E501


        :return: The source of this Event.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this Event.


        :param source: The source of this Event.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def sales_channel(self):
        """Gets the sales_channel of this Event.  # noqa: E501


        :return: The sales_channel of this Event.  # noqa: E501
        :rtype: str
        """
        return self._sales_channel

    @sales_channel.setter
    def sales_channel(self, sales_channel):
        """Sets the sales_channel of this Event.


        :param sales_channel: The sales_channel of this Event.  # noqa: E501
        :type: str
        """

        self._sales_channel = sales_channel

    @property
    def user(self):
        """Gets the user of this Event.  # noqa: E501


        :return: The user of this Event.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Event.


        :param user: The user of this Event.  # noqa: E501
        :type: str
        """

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Nomad Hawk

    This is the API descriptor for the Nomad Hawk API, responsible for tracking and analytics.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "nomad-hawk"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Nomad Hawk",
    author_email="paul@samarkand.global",
    url="https://gitlab.com/samarkand-nomad/envoy",
    keywords=["Swagger", "Nomad Hawk"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    This is the API descriptor for the Nomad Hawk API, responsible for tracking and analytics.  # noqa: E501
    """
)
